@@ -1,12 +1,12 @@
 const DOCUMENTATION_OPTIONS = {
-    VERSION: '1.13.0',
+    VERSION: '1.15.1',
     LANGUAGE: 'en',
     COLLAPSE_INDEX: false,
     BUILDER: 'html',
     FILE_SUFFIX: '.html',
     LINK_SUFFIX: '.html',
     HAS_SOURCE: true,
-    SOURCELINK_SUFFIX: '.txt',
+    SOURCELINK_SUFFIX: '',
     NAVIGATION_WITH_KEYS: false,
     SHOW_SEARCH_SUMMARY: true,
     ENABLE_SEARCH_SHORTCUTS: true,
